@@ -1,6 +1,6 @@
 package DateTimeX::Format::Excel;
 our $AUTHORITY = 'cpan:JANDREW';
-use version 0.77; our $VERSION = version->declare("v0.12.38");
+use version 0.77; our $VERSION = version->declare("v0.12.44");
 use	5.010;
 use	strict;
 use	warnings;
@@ -202,8 +202,8 @@ DateTimeX::Format::Excel - Microsofty conversion of Excel epochs
 	<img src='https://coveralls.io/repos/jandrew/DateTimeX-Format-Excel/badge.svg?branch=master' alt='Coverage Status' />
 </a>
 
-<a>
-	<img src="https://img.shields.io/badge/this version-v0.12.38-brightgreen.svg" alt="this version">
+<a href='https://github.com/jandrew/DateTimeX-Format-Excel'>
+	<img src="https://img.shields.io/github/tag/jandrew/DateTimeX-Format-Excel.svg?label=github level" alt="github level"/>
 </a>
 
 <a href="https://metacpan.org/pod/DateTimeX::Format::Excel">
@@ -513,6 +513,8 @@ B<1.> Add an error attribute to load soft failures or warnings to
 
 B<2.> Convert Smart::Comments to L<Log::Shiras|https://github.com/jandrew/Log-Shiras> debug lines
 
+B<3.> Allow localization as an input to the data so the object output will localize (DateTime::Local)
+
 =back
 
 =head1 AUTHOR
@@ -533,7 +535,7 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2014 - 2015 by Jed Lund
+This software is copyrighted (c) 2014 - 2016 by Jed Lund
 
 =head1 DEPENDENCIES
 
